@@ -152,18 +152,19 @@
 
 // Forward declarations.
 namespace gnash {
-  class bitmap_info;
-  class rect;
-  class rgba;
-  class matrix;
-  class cxform;
-  
-  class shape_character_def;
-  class generic_character;
+    class bitmap_info;
+    class rect;
+    class rgba;
+    class matrix;
+    class cxform;
+
+    class shape_character_def;
+    class generic_character;
+
+    // @@ forward decl to avoid including base/image.h; TODO change the
+    // render_handler interface to not depend on these classes at all.
+    namespace image { class ImageBase; class ImageRGB; class ImageRGBA; }
 }
-// @@ forward decl to avoid including base/image.h; TODO change the
-// render_handler interface to not depend on these classes at all.
-namespace image { class image_base; class rgb; class rgba; }
 
 namespace gnash {
 
@@ -202,6 +203,17 @@ public:
 class DSOEXPORT render_handler
 {
 public:
+  enum antialias_method
+  {
+    ANTIALIAS_DEFAULT, // Whatever the renderer prefers
+    ANTIALIAS_NONE,    // Disabled
+
+    ANTIALIAS_MULTISAMPLE, // OpenGL ARB_multisample extension
+    ANTIALIAS_ACCUM,       // OpenGL accumulation buffer
+
+    ANTIALIAS_GRAY        // Cairo single-color antialiasing
+  };
+ 
   virtual ~render_handler() {}
 
   // Your handler should return these with a ref-count of 0.  (@@ is that the right policy?)
@@ -210,7 +222,7 @@ public:
   /// Given an image, returns a pointer to a bitmap_info class
   /// that can later be passed to fill_styleX_bitmap(), to set a
   /// bitmap fill style.
-  virtual bitmap_info*  create_bitmap_info_rgb(image::rgb* im) = 0;
+  virtual bitmap_info*  create_bitmap_info_rgb(image::ImageRGB* im) = 0;
 
   /// \brief
   /// Given an image, returns a pointer to a bitmap_info class
@@ -219,28 +231,13 @@ public:
   //
   /// This version takes an image with an alpha channel.
   ///
-  virtual bitmap_info*  create_bitmap_info_rgba(image::rgba* im) = 0;
+  virtual bitmap_info*  create_bitmap_info_rgba(image::ImageRGBA* im) = 0;
 
-  /// Delete the given bitmap info class.
-  virtual void  delete_bitmap_info(bitmap_info* bi) = 0;
-
-  /// The different video frame formats
-  enum video_frame_format
-  {
-    NONE,
-    YUV,
-    RGB
-  };
-
-  /// Returns the format the current renderer wants videoframes in.
-  virtual int videoFrameFormat() = 0;
-  
   /// Draws a video frame. 
   //
-  /// The frame has already been decoded and is available in the format
-  /// specified by videoFrameFormat().    
+  /// The frame has already been decoded and is available in RGB format only.    
   ///         
-  /// @param frame The RGB or YUV video buffer frame.
+  /// @param frame The RGB video buffer frame.
   ///   Ownership of the buffer is left to the caller.
   ///
   /// @param mat The matrix with world coordinates used to retrieve the x
@@ -256,7 +253,7 @@ public:
   ///   The width and height determine the size of the Flash video instance
   ///   on the stage (in TWIPS) prior to matrix transformations.         
   ///
-  virtual void drawVideoFrame(image::image_base* frame, const matrix* mat, const rect* bounds) = 0;
+  virtual void drawVideoFrame(image::ImageBase* frame, const matrix* mat, const rect* bounds) = 0;
 
   /// Sets the update region (called prior to begin_display).
   //
@@ -327,10 +324,19 @@ public:
 
   virtual void  end_display() = 0;
     
-  /// Draw a line-strip directly, using a thin, solid line. 
+  /// Draw a line-strip directly, using a thin, solid line.
   //
   /// Can be used to draw empty boxes and cursors.
-  virtual void  draw_line_strip(const void* coords, int vertex_count,
+  ///
+  /// @coords an array of 16-bit signed integer coordinates. Even indices
+  ///         (and 0) are x coordinates, while uneven ones are y coordinates.
+  ///
+  /// @vertex_count the number of x-y coordinates (vertices).
+  ///
+  /// @color the color to be used to draw the line strip.
+  ///
+  /// @mat the matrix to be used to transform the vertices.
+  virtual void  draw_line_strip(const boost::int16_t* coords, int vertex_count,
       const rgba& color, const matrix& mat) = 0;
     
   /// Draw a simple, solid filled polygon with a thin (~1 pixel) outline.
@@ -389,7 +395,6 @@ public:
   virtual void draw_shape_character(shape_character_def *def, 
     character *inst)
   {
-
     // check if the character needs to be rendered at all
     rect cur_bounds;
 
@@ -399,20 +404,17 @@ public:
     if (!bounds_in_clipping_area(cur_bounds))
     {
         return; // no need to draw
-    }
-      
+    }    
 
     // TODO: I don't like that there is a draw_shape_character() version with
     // arbitrary fill and line styles as this may break caching...
 
     // render the character
     draw_shape_character(def, 
-    inst->get_world_matrix(), 
-    inst->get_world_cxform(),
-    inst->get_parent()->get_pixel_scale(),
-    def->get_fill_styles(),
-    def->get_line_styles());
-
+        inst->get_world_matrix(), 
+        inst->get_world_cxform(),
+        def->get_fill_styles(),
+        def->get_line_styles());
   }
   
   /// \brief
@@ -456,7 +458,6 @@ public:
   virtual void draw_shape_character(shape_character_def *def, 
     const matrix& mat,
     const cxform& cx,
-    float pixel_scale,
     const std::vector<fill_style>& fill_styles,
     const std::vector<line_style>& line_styles) = 0;
     
@@ -474,11 +475,8 @@ public:
   /// @param mat
   ///
   /// @param color
-  ///
-  /// @param pixel_scale
-  ///
   virtual void draw_glyph(shape_character_def *def, const matrix& mat,
-    const rgba& color, float pixel_scale) = 0;
+    const rgba& color) = 0;
 
   /// This function returns the color at any position in the stage. It is used
   /// for automatic testing only, it should not be used for anything else!
