@@ -1,5 +1,5 @@
 // 
-//   Copyright (C) 2005, 2006, 2007 Free Software Foundation, Inc.
+//   Copyright (C) 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #define __FILEIO_PLUGIN_H__
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "gnashconfig.h"
 #endif
 
 #include <memory> // for auto_ptr
@@ -52,8 +52,10 @@ public:
     int fseek(long offset);
     int fseek(long offset, int whence);
     long ftell();
+    bool asyncmode(bool async); 
+    bool feof();
     bool unlink(const std::string &filespec);
-    void scandir(const std::string& dir, as_value* result);
+    void scandir(const std::string& dir, as_value* result);    
 private:
     FILE        *_stream;
     std::string _filespec;
