@@ -18,14 +18,16 @@
 #include "gtk_glue.h"
 
 #include <gtk/gtk.h>
+#ifndef _WIN32
 #include <gdk/gdkx.h>
+#else
+#include <gdk/gdk.h>
+#endif
 
 #include <gtk/gtkgl.h>
 
 #include "tu_opengl_includes.h"
 
-using namespace std;
-
 
 namespace gnash
 {
