@@ -15,8 +15,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-#ifndef __GTKSUP_H__
-#define __GTKSUP_H__
+#ifndef GNASH_GTKSUP_H
+#define GNASH_GTKSUP_H
 
 #ifdef HAVE_CONFIG_H
 #include "gnashconfig.h"
@@ -25,11 +25,7 @@
 #include "gnash.h"
 #include "gtk_glue.h"
 
-#ifndef _WIN32
-#include <gdk/gdkx.h>
-#else
 #include <gdk/gdk.h>
-#endif
 #include <gtk/gtk.h>
 
 #ifdef GUI_HILDON
@@ -181,10 +177,10 @@ class GtkGui : public Gui
     
     void add_pixmap_directory(const gchar *directory);
 
-    gchar* find_pixmap_file(const gchar *filename);
-    
-    void rerenderPixels(int xmin, int ymin, int xmax, int ymax);
+    static gchar* find_pixmap_file(const gchar *filename);
     
+    void expose(const GdkRegion* region);
+
     void setInvalidatedRegions(const InvalidatedRanges& ranges);
 
     bool want_multiple_regions() { return true; }
@@ -195,6 +191,9 @@ class GtkGui : public Gui
 
     virtual void showMenu(bool show);
 
+    // Adds the gnash icon to a window.
+    static void addGnashIcon(GtkWindow* window);
+
  private:
 #ifdef GUI_HILDON
     HildonProgram *_hildon_program;
@@ -212,11 +211,6 @@ class GtkGui : public Gui
     GtkWidget   *_menubar;
     GtkWidget   *_vbox;
 
-    std::vector< geometry::Range2d<int> > _drawbounds;
-
-    // Adds the gnash icon to a window.
-    void addGnashIcon(GtkWindow* window);
-
     /// Add key press events to the toplevel window.
     //
     /// The plugin fullscreen creates a new top level
@@ -224,7 +218,7 @@ class GtkGui : public Gui
     /// the drawing area is reparented.
     void setupWindowEvents();
     
-    GdkPixbuf* createPixbuf(const gchar *filename);
+    static GdkPixbuf* createPixbuf(const gchar *filename);
 
 #ifdef USE_SWFTREE
     // Create a tree model for displaying movie info
@@ -236,40 +230,12 @@ class GtkGui : public Gui
     static gnash::key::code gdk_to_gnash_key(guint key);
     static int gdk_to_gnash_modifier(int state);
 
-    // A struct containing pointers to widgets for passing preference 
-    // data from the dialogue   
-    struct prefData {
-        GtkWidget *soundToggle;
-        GtkWidget *actionDumpToggle;
-        GtkWidget *parserDumpToggle;
-        GtkWidget *malformedSWFToggle;
-        GtkWidget *ASCodingErrorToggle;
-        GtkWidget *logfileName;
-        GtkWidget *writeLogToggle;
-        GtkWidget *verbosityScale;
-        GtkWidget *localDomainToggle;
-        GtkWidget *localHostToggle;
-        GtkWidget *solReadOnlyToggle;
-        GtkWidget *solLocalDomainToggle;
-        GtkWidget *localConnectionToggle;
-        GtkWidget *insecureSSLToggle; 
-        GtkWidget *lcTraceToggle;
-        GtkWidget *solSandbox;
-        GtkWidget *osText;
-        GtkWidget *versionText;
-        GtkWidget *urlOpenerText;
-        GtkWidget *librarySize;
-        GtkWidget *startStoppedToggle;
-#ifdef USE_DEBUGGER
-        GtkWidget *DebuggerToggle;
-#endif
-    };
-    
-    static void handlePrefs(GtkWidget* widget, gint response, gpointer data);
     static void openFile(GtkWidget* dialog, gpointer data);
 
     void stopHook();
     void playHook();
+
+    guint _advanceSourceTimer;
 };
 
 // end of namespace gnash 
