@@ -1,4 +1,4 @@
-// gui.cpp:  Top level GUI for flash player, for Gnash.
+// gui.cpp:  Top level GUI for SWF player, for Gnash.
 // 
 //   Copyright (C) 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 // 
@@ -32,10 +32,12 @@
 
 #ifdef GNASH_FPS_DEBUG
 #include "ClockTime.h"
+#include <boost/format.hpp>
 #endif
 
 #include <cstdio>
 #include <cstring>
+#include <algorithm> // std::max, std::min
 
 #ifdef SKIP_RENDERING_IF_LATE
 #include "WallClockTimer.h"
@@ -83,6 +85,7 @@ Gui::Gui() :
     _fullscreen(false),
     _mouseShown(true),
     _maxAdvances(0),
+    _advances(0),
     _xscale(1.0f),
     _yscale(1.0f),
     _xoffset(0),
@@ -108,7 +111,7 @@ Gui::Gui() :
     ,_keyboardMouseMovementsStep(1)
 #endif
 {
-//    GNASH_REPORT_FUNCTION;
+
 }
 
 Gui::Gui(unsigned long xid, float scale, bool loop, unsigned int depth)
@@ -124,6 +127,7 @@ Gui::Gui(unsigned long xid, float scale, bool loop, unsigned int depth)
     _fullscreen(false),
     _mouseShown(true),
     _maxAdvances(0),
+    _advances(0),
     _xscale(scale),
     _yscale(scale),
     _xoffset(0), // TODO: x and y offset will need update !
@@ -153,10 +157,11 @@ Gui::Gui(unsigned long xid, float scale, bool loop, unsigned int depth)
 
 Gui::~Gui()
 {
-//    GNASH_REPORT_FUNCTION;
+    if ( _movieDef.get() ) log_debug("~Gui - _movieDef refcount: %d", _movieDef->get_ref_count());
+
     delete _renderer;
 #ifdef GNASH_FPS_DEBUG
-    printf("Total frame advances: %u\n", fps_counter_total);
+    std::cerr << "Total frame advances: " << fps_counter_total << std::endl;
 #endif
 }
 
@@ -175,25 +180,27 @@ Gui::unsetFullscreen()
 bool
 Gui::showMouse(bool /* show */)
 {
-	static bool warned = false;
-	if (!warned)
-	{
-    	log_unimpl(_("Mouse show/hide not yet supported in this GUI"));
-    	warned = true;
-   	}
-   	
+	LOG_ONCE(log_unimpl(_("Mouse show/hide not yet supported in this GUI")));
    	return true;
 }
 
 void
 Gui::showMenu(bool /* show */)
 {
-	static bool warned = false;
-	if (!warned)
+	LOG_ONCE(log_unimpl(_("menushow not yet supported in this GUI")));
+}
+
+void
+Gui::allowScale(bool allow)
+{
+	if ( ! _stage )
 	{
-    	log_unimpl(_("menushow not yet supported in this GUI"));
-    	warned = true;
-   	}
+		log_error("Gui::allowScale called before a movie_root was available");
+		return;
+	}
+
+	if ( allow ) _stage->setStageScaleMode(movie_root::showAll);
+	else _stage->setStageScaleMode(movie_root::noScale);
 }
 
 void
@@ -208,16 +215,11 @@ Gui::toggleFullscreen()
 }
 
 void
-Gui::menu_restart()
+Gui::restart()
 {
-//    GNASH_REPORT_FUNCTION;
-
 	_stage->reset();
 	_started = false;
 	start();
-
-	//_stage->restart();
-
 }
 
 void
@@ -402,90 +404,46 @@ Gui::resize_view(int width, int height)
 
 	_width = width;
 	_height = height;
-	_validbounds.setTo(0, 0, _width-1, _height-1);
+	_validbounds.setTo(0, 0, _width, _height);
 
 	updateStageMatrix();
 
 	if ( _stage && _started ) display(_stage);
 }
 
-void
-Gui::menu_quit()
-{
-//    GNASH_REPORT_FUNCTION;
-    quit();
-}
-
-void
-Gui::menu_play()
-{
-//    GNASH_REPORT_FUNCTION;
-    //get_current_root()->set_play_state(gnash::sprite_instance::PLAY);
-    play();
-}
-
-void
-Gui::menu_pause()
-{
-//    GNASH_REPORT_FUNCTION;
-
-    pause();
-//    movie_root* m = get_current_root();
-//    if (m->get_play_state() == gnash::sprite_instance::STOP) {
-//      m->set_play_state(gnash::sprite_instance::PLAY);
-//    } else {
-//      m->set_play_state(gnash::sprite_instance::STOP);
-//    }
-
-}
-
-void
-Gui::menu_stop()
-{
-//    GNASH_REPORT_FUNCTION;
-    //get_current_root()->set_play_state(gnash::sprite_instance::STOP);
-    stop();
-}
 
 void
 Gui::menu_step_forward()
 {
-//    GNASH_REPORT_FUNCTION;
-	movie_root* m = get_current_root();
-	m->goto_frame(m->get_current_frame()+1);
+	movie_root& m = VM::get().getRoot();
+	m.goto_frame(m.get_current_frame()+1);
 }
 
 void
 Gui::menu_step_backward()
 {
-//    GNASH_REPORT_FUNCTION;
-
-	movie_root* m = get_current_root();
-	m->goto_frame(m->get_current_frame()-1);
+	movie_root& m = VM::get().getRoot();
+	m.goto_frame(m.get_current_frame()-1);
 }
 
 void
 Gui::menu_jump_forward()
 {
-//    GNASH_REPORT_FUNCTION;
-
-	movie_root* m = get_current_root();
-	m->goto_frame(m->get_current_frame()+10);
+	movie_root& m = VM::get().getRoot();
+	m.goto_frame(m.get_current_frame()+10);
 }
 
 void
 Gui::menu_jump_backward()
 {
-//    GNASH_REPORT_FUNCTION;
-
-	movie_root* m = get_current_root();
-	m->goto_frame(m->get_current_frame()-10);
+	movie_root& m = VM::get().getRoot();
+	m.goto_frame(m.get_current_frame()-10);
 }
 
 void
-Gui::menu_toggle_sound()
+Gui::toggleSound()
 {
-//    GNASH_REPORT_FUNCTION;
+
     media::sound_handler* s = get_sound_handler();
 
     if (!s)
@@ -509,10 +467,10 @@ Gui::notify_mouse_moved(int ux, int uy)
 	if ( _stopped ) return;
 
 	// A stage pseudopixel is user pixel / _xscale wide
-	float x = (ux-_xoffset) / _xscale;
+	boost::int32_t x = (ux-_xoffset) / _xscale;
 
 	// A stage pseudopixel is user pixel / _xscale high
-	float y = (uy-_yoffset) / _yscale;
+	boost::int32_t y = (uy-_yoffset) / _yscale;
 
 #ifdef DEBUG_MOUSE_COORDINATES
 	log_debug(_("mouse @ %d,%d"), x, y);
@@ -607,11 +565,11 @@ Gui::notify_key_event(gnash::key::code k, int modifier, bool pressed)
 			{
 				case gnash::key::r:
 				case gnash::key::R:
-					menu_restart();
+					restart();
 					break;
 				case gnash::key::p:
 				case gnash::key::P:
-					menu_pause();
+					pause();
 					break;
 				case gnash::key::l:
 				case gnash::key::L:
@@ -621,7 +579,7 @@ Gui::notify_key_event(gnash::key::code k, int modifier, bool pressed)
 				case gnash::key::Q:
 				case gnash::key::w:
 				case gnash::key::W:
-					menu_quit();
+					quit();
 					break;
 				case gnash::key::f:
 				case gnash::key::F:
@@ -633,6 +591,31 @@ Gui::notify_key_event(gnash::key::code k, int modifier, bool pressed)
 				case gnash::key::LEFT_BRACKET:
 					menu_step_backward();
 					break;
+				case gnash::key::MINUS:
+				{
+					// Max interval allowed: 1 second (1FPS)
+					unsigned int ni = std::min(_interval+2, 1000u);
+					setInterval(ni);
+					break;
+                                }
+				case gnash::key::PLUS:
+				{
+					// Min interval allowed: 1/100 second (100FPS)
+					unsigned int ni = std::max(_interval-2, 10u);
+					setInterval(ni);
+					break;
+                                }
+				case gnash::key::EQUALS:
+				{
+					if ( _stage )
+					{
+						float fps = _stage->get_movie_definition()->get_frame_rate();
+						// Min interval allowed: 1/100 second (100FPS)
+						unsigned int ni = 1000.0/fps;
+						setInterval(ni);
+					}
+					break;
+                                }
 				default:
 					break;
 			}
@@ -827,8 +810,9 @@ Gui::display(movie_root* m)
 				corners[2].y = ymax;
 				corners[3].x = xmin;
 				corners[3].y = ymax;
-				gnash::render::draw_poly(&corners[0], 4,
-					rgba(0,0,0,0), rgba(255,0,0,255), matrix::identity, false);
+				matrix no_transform;
+				gnash::render::draw_poly(corners, 4,
+					rgba(0,0,0,0), rgba(255,0,0,255), no_transform, false);
 					
 			}
 		}
@@ -849,6 +833,11 @@ Gui::play()
 
     _stopped = false;
     if ( ! _started ) start();
+    else
+    {
+        media::sound_handler* s = get_sound_handler();
+        if ( s ) s->unpause();
+    }
 
     playHook ();
 }
@@ -861,6 +850,9 @@ Gui::stop()
 
     _stopped = true;
 
+    media::sound_handler* s = get_sound_handler();
+    if ( s ) s->pause();
+
     stopHook();
 }
 
@@ -871,7 +863,12 @@ Gui::pause()
     {
         play();
     }
-    else _stopped = true;
+    else
+    {
+    	media::sound_handler* s = get_sound_handler();
+    	if ( s ) s->pause();
+        _stopped = true;
+    }
 }
 
 void
@@ -888,24 +885,25 @@ Gui::start()
     mr->setVariables(_flashVars);
 
     _stage->setRootMovie( mr.release() ); // will construct the instance
-    _stage->set_display_viewport(0, 0, _width, _height);
+    resize_view(_width, _height); // to properly update stageMatrix if scaling is given 
 
     bool background = true; // ??
     _stage->set_background_alpha(background ? 1.0f : 0.05f);
 
+    media::sound_handler* s = get_sound_handler();
+    if ( s ) s->unpause();
     _started = true;
 }
 
 bool
 Gui::advanceMovie()
 {
-    static unsigned long advances = 0;
 
 	if ( isStopped() ) return true;
 
     if ( ! _started ) start();
   
-//	GNASH_REPORT_FUNCTION;
+
 
 #ifdef SKIP_RENDERING_IF_LATE
 	WallClockTimer advanceTimer;
@@ -987,7 +985,7 @@ Gui::advanceMovie()
 	}
 
     /// Quit if we've reached the advance limit.
-    if (_maxAdvances && (advances++ > _maxAdvances))
+    if (_maxAdvances && (_advances++ > _maxAdvances))
     {
         quit();
     }
@@ -1006,12 +1004,6 @@ Gui::want_redraw()
     return false;
 }
 
-bool
-Gui::loops()
-{
-    return _loop;
-}
-
 void
 Gui::setInvalidatedRegion(const rect& /*bounds*/)
 {
@@ -1136,7 +1128,6 @@ Gui::getMovieInfo() const
 void 
 Gui::fpsCounterTick()
 {
-  // GNASH_REPORT_FUNCTION;
 
   // increment this *before* the early return so that
   // frame count on exit is still valid
@@ -1171,7 +1162,7 @@ Gui::fpsCounterTick()
       // the timers are unsigned, so when the clock runs "backwards" it leads
       // to a very high difference value. In theory, this should never happen
       // with ticks, but it does on my machine (which may have a hw problem?).
-      printf("Time glich detected, need to restart FPS counters, sorry...\n");
+      std::cerr << "Time glitch detected, need to restart FPS counters, sorry..." << std::endl;
       
       fps_timer = current_timer;
       fps_start_timer = current_timer;
@@ -1185,16 +1176,18 @@ Gui::fpsCounterTick()
       fps_rate_min = rate;
       fps_rate_max = rate; 
     } else {
-      fps_rate_min = fmin(fps_rate_min, rate);
-      fps_rate_max = fmax(fps_rate_max, rate);
+      fps_rate_min = std::min<float>(fps_rate_min, rate);
+      fps_rate_max = std::max<float>(fps_rate_max, rate);
     }
     
     float avg = fps_counter_total / secs_total; 
   
     //log_debug("Effective frame rate: %0.2f fps", (float)(fps_counter/secs));
-    printf("Effective frame rate: %0.2f fps (min %0.2f, avg %0.2f, max %0.2f, "
-      "%u frames in %0.1f secs total)\n", rate, fps_rate_min, avg, fps_rate_max,
-      fps_counter_total, secs_total);
+    std::cerr << boost::format("Effective frame rate: %0.2f fps "
+                               "(min %0.2f, avg %0.2f, max %0.2f, "
+                               "%u frames in %0.1f secs total)") % rate %
+                               fps_rate_min % avg % fps_rate_max %
+                               fps_counter_total % secs_total << std::endl;
       
     fps_counter = 0;
     fps_timer = current_timer;
@@ -1226,6 +1219,14 @@ Gui::setStage(movie_root* stage)
     assert(stage);
     assert(!_stage);
     _stage = stage;
+    _stage->setGui(this);
+}
+
+bool
+Gui::yesno(const std::string& question)
+{
+    log_error("This gui didn't override 'yesno', assuming 'yes' answer to question: %s", question);
+    return true;
 }
 
 // end of namespace
