@@ -30,6 +30,7 @@
 #include "log.h"
 #include "amf.h"
 #include "amfutf8.h"
+#include "utility.h"
 #include "element.h"
 #include <boost/cstdint.hpp> // for boost::?int??_t
 
@@ -58,12 +59,11 @@ const char *astype_str[] = {
     "Recordset",
     "XMLObject",
     "TypedObject",
-    "Varible (gnash)",
-    "Function (gnash)"
+    "AMF3 Data"
 };
 
 Element::Element()
-    : _name(),
+    : _name(0),
       _buffer(0),
       _type(NOTYPE)
 {
@@ -74,19 +74,23 @@ Element::Element()
 Element::~Element()
 {
 //    GNASH_REPORT_FUNCTION;
-    if (_buffer) {
-	delete _buffer;
-    }
     for (size_t i=0; i< _properties.size(); i++) {
 	delete _properties[i];
     }
-    if (_name) {
-	delete[] _name;
-    }
+    // FIXME: for some odd reason, on rare occasions deleting this buffer
+    // makes valgrind complain. It looks like memory corruption caused by something
+    // else, but neither valgrind nor GDB can find it. We could always not delete
+    // the buffer to keep valgrind happy, but then we leak memory. As the problem
+    // appears to be that _buffer has a bogus address that doesn't match any allocated
+    // Element, we assume this is a bug in our test case, but add comment here to be
+    // paranoid.
+//    delete _buffer;
+    delete[] _name;
 }
 
+
 Element::Element(Network::byte_t *indata) 
-    : _name(),
+    : _name(0),
       _buffer(0),
       _type(NOTYPE)
 {
@@ -95,7 +99,7 @@ Element::Element(Network::byte_t *indata)
 }
 
 Element::Element(double indata)
-    : _name(),
+    : _name(0),
       _buffer(0),
       _type(NOTYPE)
 {
@@ -110,7 +114,7 @@ Element::Element(double indata)
 // }
 
 Element::Element(const string &indata)
-    : _name(),
+    : _name(0),
       _buffer(0),
       _type(NOTYPE)
 {
@@ -119,7 +123,7 @@ Element::Element(const string &indata)
 }
 
 Element::Element(const string &name, const string &indata)
-    : _name(),
+    : _name(0),
       _buffer(0),
       _type(NOTYPE)
 {
@@ -128,7 +132,7 @@ Element::Element(const string &name, const string &indata)
 }
 
 Element::Element(const string &name, bool indata)
-    : _name(),
+    : _name(0),
       _buffer(0),
       _type(NOTYPE)
 {
@@ -137,7 +141,7 @@ Element::Element(const string &name, bool indata)
 }
 
 Element::Element(bool indata)
-    : _name(),
+    : _name(0),
       _buffer(0),
       _type(NOTYPE)
 {
@@ -148,7 +152,7 @@ Element::Element(bool indata)
 // Create a function block for AMF
 Element::Element(bool flag, double unknown1, double unknown2,
 		 const string &methodname)
-    : _name(),
+    : _name(0),
       _buffer(0),
       _type(NOTYPE)
 {
@@ -265,16 +269,14 @@ void
 Element::clear()
 {
 //    GNASH_REPORT_FUNCTION;
-    if (_name) {
 	delete [] _name;
-    }
-    if (_buffer) {
+	_name = 0;
 	delete _buffer;
-    }
+	_buffer = 0;
 }
 
 Network::byte_t *
-Element::getData()
+Element::getData() const
 {
 //    GNASH_REPORT_FUNCTION;
     if (_buffer) {
@@ -284,7 +286,7 @@ Element::getData()
 };
 
 size_t
-Element::getLength()
+Element::getLength() const
 {
 //    GNASH_REPORT_FUNCTION;
     if (_buffer) {
@@ -294,7 +296,7 @@ Element::getLength()
 };
 
 double
-Element::to_number()
+Element::to_number() const
 {
 //    GNASH_REPORT_FUNCTION;
     if (_buffer) {
@@ -305,7 +307,7 @@ Element::to_number()
 }
 
 const char *
-Element::to_string()
+Element::to_string() const
 {
 //    GNASH_REPORT_FUNCTION;
     if (_buffer) {
@@ -318,7 +320,7 @@ Element::to_string()
 };
 
 bool
-Element::to_bool()
+Element::to_bool() const
 {
 //    GNASH_REPORT_FUNCTION;
     if (_buffer) {
@@ -399,26 +401,31 @@ Element::encode()
 {
 //    GNASH_REPORT_FUNCTION;
     Buffer *buf = 0;
+    size_t size = 0;
     if (_type == Element::OBJECT_AMF0) {
 	// FIXME: we probably want a better size, to avoid the other
 	// appends from having to resize and copy the data all the time.
-	buf = new Buffer(300);
+	for (size_t i=0; i<_properties.size(); i++) {
+	    size += _properties[i]->getLength() + _properties[i]->getNameSize() + AMF_VAR_HEADER_SIZE;
+	}
+	buf = new Buffer(size);
 	buf->clear();		// FIXME: temporary, makes buffers cleaner in gdb.
 	buf->append(Element::OBJECT_AMF0);
 	if (_name > 0) {
-// 	    Buffer *top = AMF::encodeElement(this);
-// 	    buf->append(top);
-	    buf->append(reinterpret_cast<Network::byte_t *>(_name), getNameSize());
 	    size_t length = getNameSize();
 	    boost::uint16_t enclength = length;
 	    swapBytes(&enclength, 2);
 	    buf->append(enclength);
+	    string str = _name;
+	    buf->append(str);
+	    Network::byte_t byte = static_cast<Network::byte_t>(0x5);
+	    buf->append(byte);
 	}
 
 	for (size_t i=0; i<_properties.size(); i++) {
 	    Buffer *partial = AMF::encodeElement(_properties[i]);
-	    log_debug("Encoded partial size for is %d", partial->size());
-	    partial->dump();
+//	    log_debug("Encoded partial size for is %d", partial->size());
+//	    partial->dump();
 	    if (partial) {
 		buf->append(partial);
 		delete partial;
@@ -426,7 +433,7 @@ Element::encode()
 		break;
 	    }
 	}
-	log_debug("FIXME: Terminating object");
+//	log_debug("FIXME: Terminating object");
 	Network::byte_t pad = 0;
 	buf->append(pad);
 	buf->append(pad);
@@ -462,7 +469,7 @@ Element::operator=(Element &el)
 Element &
 Element::operator=(Element *el)
 {
-    GNASH_REPORT_FUNCTION;
+//    GNASH_REPORT_FUNCTION;
     _type = el->getType();
     if (el->getNameSize()) {
         _name = strdup(el->getName());
@@ -485,16 +492,18 @@ Element::makeString(Network::byte_t *data, size_t size)
 {
 //    GNASH_REPORT_FUNCTION;
     _type = Element::STRING_AMF0;
+
     // Make room for an additional NULL terminator
     check_buffer(size+1);
+    _buffer->clear();		// FIXME: this could be a performance issue
     _buffer->copy(data, size);
     
     // Unlike other buffers, people like to print strings, so we must add
     // a NULL terminator to the string. When encoding, we are careful to
     // to adjust the byte count down by one, as the NULL terminator doesn't
     // get written.
-    *(_buffer->end() - 1) = 0;
-
+//     *(_buffer->end() - 1) = 0;
+    _buffer->setSize(size);
     return *this;
 }
 
@@ -536,6 +545,13 @@ Element::makeString(const string &name, const string &str)
     return makeString(str.c_str(), str.size());
 }
 
+Element &
+Element::makeNumber(Buffer *buf)
+{
+//    GNASH_REPORT_FUNCTION;
+    return makeNumber(buf->reference());
+}
+
 Element &
 Element::makeNumber(Network::byte_t *data)
 {
@@ -588,7 +604,8 @@ Element::makeBoolean(bool flag)
 //    GNASH_REPORT_FUNCTION;
     _type = Element::BOOLEAN_AMF0;
     check_buffer(sizeof(bool));
-    _buffer->append(flag);
+    *(_buffer->reference()) = flag;
+
     return *this;
 }
 
@@ -629,13 +646,12 @@ Element::makeUndefined(const std::string &name)
     return makeUndefined();
 }
 
+// a NULL amf Object consists of a single byte, which is the type
 Element &
 Element::makeNull()
 {
 //    GNASH_REPORT_FUNCTION;
     _type = Element::NULL_AMF0;
-    check_buffer(sizeof(Network::byte_t));
-    *(_buffer->reference()) = 0;
     return *this;
 }
 
@@ -875,6 +891,14 @@ Element::setName(const string &str)
     *(_name + str.size()) = 0;
 }
 
+void
+Element::setName(const char *name, size_t size)
+{
+//    GNASH_REPORT_FUNCTION;
+    Network::byte_t *ptr = reinterpret_cast<Network::byte_t *>(const_cast<char *>(name));
+    return setName(ptr, size);
+}
+
 void
 Element::setName(Network::byte_t *name, size_t size)
 {
@@ -905,30 +929,29 @@ Element::check_buffer(size_t size)
 }
 
 void
-Element::dump()
+Element::dump(std::ostream& os) const
 {
 //    GNASH_REPORT_FUNCTION;
     
     if (_name) {
- 	cerr << "AMF object name: " << _name << ", length is " << getLength() << endl;
+ 	os << "AMF object name: " << _name << ", length is " << getLength() << endl;
     }
 
-    cerr << astype_str[_type] << ": ";
+    os << astype_str[_type] << ": ";
 
     switch (_type) {
       case Element::NUMBER_AMF0:
-	  cerr << to_number() << endl;
+	  os << to_number() << endl;
 	  break;
       case Element::BOOLEAN_AMF0:
-	  cerr << (to_bool() ? "true" : "false") << endl;
+	  os << (to_bool() ? "true" : "false") << endl;
 	  break;
       case Element::STRING_AMF0:
-	  cerr << "(" << getLength() << " bytes): ";
+	  os << "(" << getLength() << " bytes): ";
 	  if (getLength() > 0) {
-	      cerr << "\t\"" << to_string() << "\"" << endl;
-	  } else {
-	      cerr << endl;
+	      cerr << "\t\"" << to_string() << "\"";
 	  }
+	  cerr << endl;
 	  break;
       case Element::OBJECT_AMF0:
 	  break;
@@ -945,12 +968,15 @@ Element::dump()
       case Element::RECORD_SET_AMF0:
       case Element::XML_OBJECT_AMF0:
       case Element::TYPED_OBJECT_AMF0:
-//	  cerr << "AMF data is: 0x" << hexify(_data, _length, false) << endl;
-	  log_debug("FIXME: got a typed object!");
+      case Element::AMF3_DATA:
+	  if (getLength() != 0) {
+	      log_debug("FIXME: got AMF3 data!");
+	  }
+//	  cerr << "AMF3 data is: 0x" << hexify(_data, _length, false) << endl;
 	  break;
 //       case Element::VARIABLE:
 //       case Element::FUNCTION:
-//  	  cerr << "# of properties in object: " << properties.size() << endl;
+//  	  os << "# of properties in object: " << properties.size() << endl;
 // 	  for (size_t i=0; i< properties.size(); i++) {
 // 	      properties[i]->dump();
 // 	  }
@@ -959,6 +985,36 @@ Element::dump()
 //	  log_unimpl("%s: type %d", __PRETTY_FUNCTION__, (int)_type);
 	  break;
     }
+
+//     if (_buffer) {
+// 	_buffer->dump();
+//     }
+
+    if (_properties.size() > 0) {
+	vector<amf::Element *>::const_iterator ait;
+	os << "# of Properties in object: " << _properties.size() << endl;
+	for (ait = _properties.begin(); ait != _properties.end(); ait++) {
+	    const amf::Element *el = (*(ait));
+	    el->dump(os);
+	}
+    }
+}
+
+Element *
+Element::findProperty(const std::string &name)
+{
+    if (_properties.size() > 0) {
+	vector<amf::Element *>::iterator ait;
+//	cerr << "# of Properties in object: " << _properties.size() << endl;
+	for (ait = _properties.begin(); ait != _properties.end(); ait++) {
+	    amf::Element *el = (*(ait));
+	    if (el->getName() == name) {
+		return el;
+	    }
+//	    el->dump();
+	}
+    }
+    return 0;
 }
 
 } // end of amf namespace
