@@ -18,11 +18,7 @@
 #ifndef __GNASH_URL_H__
 #define __GNASH_URL_H__
 
-#ifdef HAVE_CONFIG_H
-#include "gnashconfig.h"
-#endif
-
-#include "tu_config.h"
+#include "dsodefs.h"
 
 #include <iosfwd>
 #include <string>
@@ -67,6 +63,13 @@ public:
 	///
 	const std::string& hostname() const { return _host; }
 
+	/// Return the 'port' member of this URL, as a string
+	//
+	/// NOTE: return the empty string if the port isn't specified,
+        /// as this is an optional field.
+	///
+	const std::string& port() const { return _port; }
+
 	/// Return the 'path' member of this URL, as a string
 	const std::string& path() const { return _path; }
 
@@ -160,6 +163,9 @@ private:
 	/// Extract anchor from path
 	void split_anchor_from_path();
 
+	/// Extract tcp/ip port from path
+	void split_port_from_host();
+
 	/// Extract and parse query string from path
 	void split_querystring_from_path();
 
@@ -172,17 +178,14 @@ private:
 	void normalize_path(std::string& path);
 
 	std::string _proto;
-
 	std::string _host;
-
+	std::string _port;
 	std::string _path;
-
 	std::string _anchor;
-
 	std::string _querystring;
 };
 
-std::ostream& operator<< (std::ostream&o, const URL& u);
+DSOEXPORT std::ostream& operator<< (std::ostream&o, const URL& u);
 
 } // end of gnash namespace
 
