@@ -22,23 +22,16 @@
 #include "gnashconfig.h"
 #endif
 
-#ifdef HAVE_WINSOCK2_H
-# include <io.h>
-#endif
-
 #include "rc.h" // for IF_VERBOSE_* implementation
 #include "dsodefs.h" // for DSOEXPORT
 
 #include <fstream>
-#include <sstream>
 #include <boost/thread/thread.hpp>
 #include <boost/thread/mutex.hpp>
 #include <boost/format.hpp>
 
 // the default name for the debug log
 #define DEFAULT_LOGFILE "gnash-dbg.log"
-#define TIMESTAMP_LENGTH 24             // timestamp length
-#define TIMESTAMP_FORMAT "%Y-%m-%d %H:%M:%S     " // timestamp format
 
 // Support compilation with (or without) native language support
 #include "gettext.h"
@@ -59,7 +52,7 @@
 
 namespace gnash {
 
-#define DEBUGLEVEL 2
+#define GNASH_DEBUG_LEVEL 2
 
 // This is a basic file logging class
 class DSOEXPORT LogFile {
@@ -232,7 +225,7 @@ private:
 /// This is a sequence of different log message types to be used in
 /// the code. Append the name to log_ to call the function, e.g. 
 /// log_error, log_unimpl.
-#define LOG_TYPES (error) (debug) (unimpl) (aserror) (swferror) (security) (action) (parse) (trace)
+#define LOG_TYPES (error) (debug) (unimpl) (aserror) (swferror) (smferror) (security) (action) (parse) (trace)
 
 /// This actually creates the template functions using the TOKENIZE
 /// functions above. The templates look like this:
@@ -294,6 +287,7 @@ DSOEXPORT void processLog_action(const boost::format& fmt);
 DSOEXPORT void processLog_parse(const boost::format& fmt);
 DSOEXPORT void processLog_security(const boost::format& fmt);
 DSOEXPORT void processLog_swferror(const boost::format& fmt);
+DSOEXPORT void processLog_amferror(const boost::format& fmt);
 DSOEXPORT void processLog_aserror(const boost::format& fmt);
 
 /// A fault-tolerant boost::format object for logging
@@ -332,6 +326,11 @@ DSOEXPORT std::string hexify(const unsigned char *bytes, size_t length, bool asc
 #define VERBOSE_MALFORMED_SWF 1
 #endif
 
+// Define to 0 this to remove invalid AMF verbosity at compile-time
+#ifndef VERBOSE_MALFORMED_AMF
+#define VERBOSE_MALFORMED_AMF 1
+#endif
+
 
 #if VERBOSE_PARSE
 #define IF_VERBOSE_PARSE(x) do { if ( LogFile::getDefaultInstance().getParserDump() ) { x; } } while (0);
@@ -359,6 +358,13 @@ DSOEXPORT std::string hexify(const unsigned char *bytes, size_t length, bool asc
 #define IF_VERBOSE_MALFORMED_SWF(x)
 #endif
 
+#if VERBOSE_MALFORMED_AMF
+// TODO: check if it's worth to check verbosity level too... 
+#define IF_VERBOSE_MALFORMED_AMF(x) { if ( gnash::RcInitFile::getDefaultInstance().showMalformedAMFErrors() ) { x; } }
+#else
+#define IF_VERBOSE_MALFORMED_AMF(x)
+#endif
+
 class DSOEXPORT __Host_Function_Report__ {
 public:
     const char *func;
@@ -380,7 +386,7 @@ public:
     }
 
     ~__Host_Function_Report__(void) {
-	if (LogFile::getDefaultInstance().getVerbosity() >= DEBUGLEVEL + 1) {
+	if (LogFile::getDefaultInstance().getVerbosity() >= GNASH_DEBUG_LEVEL + 1) {
 	    log_debug("returning");
 	}
     }
