@@ -19,14 +19,16 @@
 #include "gnashconfig.h"
 #endif
 
+#ifdef HAVE_PTHREADS
+#include <pthread.h>
+#endif
+
 #include "noseek_fd_adapter.h"
-#include "tu_file.h"
+#include "IOChannel.h" // for inheritance
 #include "utility.h"
-#include "GnashException.h"
 #include "log.h"
 
-#include <unistd.h>
-#include <cstring>
+#include <unistd.h> // for ::read
 
 #include <boost/scoped_array.hpp>
 
@@ -35,10 +37,8 @@
 // define this if you want seeks back to be reported (on stderr)
 //#define GNASH_NOSEEK_FD_WARN_SEEKSBACK 1
 
-
-#include <stdexcept>
-#include <cstdio>
 #include <cerrno>
+#include <cstdio>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -47,9 +47,10 @@
 #endif
 
 #include <string>
+#include <boost/format.hpp>
 
-namespace noseek_fd_adapter
-{
+namespace gnash {
+namespace noseek_fd_adapter {
 
 
 /***********************************************************************
@@ -60,7 +61,7 @@ namespace noseek_fd_adapter
  * 
  **********************************************************************/
 
-class NoSeekFile
+class NoSeekFile : public IOChannel
 {
 
 public:
@@ -80,23 +81,25 @@ public:
 
 	~NoSeekFile();
 
-	/// Read 'bytes' bytes into the given buffer.
-	//
-	/// Return number of actually read bytes
-	///
-	size_t read_cache(void *dst, size_t bytes);
+	// See IOChannel.h for description
+	virtual int read(void *dst, int bytes);
 
-	/// Return true if EOF has been reached
-	bool eof();
+	// See IOChannel for description
+	virtual bool eof() const;
 
-	/// Return zero if everything is fine (?)
-	int err() { return 0; }
+	// See IOChannel for description
+	virtual int get_error() const { return 0; }
 
-	/// Report global position within the file
-	size_t tell();
+	// See IOChannel for description
+	virtual int tell() const;
 
-	/// Put read pointer at given position
-	bool seek(size_t pos);
+	// See IOChannel for description
+	virtual int seek(int pos);
+
+	// See IOChannel for description
+	virtual void go_to_end() {
+		throw IOException("noseek_fd_adapter doesn't support seek to end");
+	}
 
 private:
 
@@ -148,48 +151,46 @@ NoSeekFile::cache(void *from, size_t sz)
 {
 
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, "cache(%p, " SIZET_FMT ") called\n", from, sz);
+	std::cerr << boost::format("cache(%p, %d) called") % from % sz << std::endl;
 #endif
 	// take note of current position
 	long curr_pos = ftell(_cache);
 
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, " current position: %ld\n", curr_pos);
+	std::cerr << boost::format(" current position: %ld)") % curr_pos << std::endl;
 #endif
 
 	// seek to the end
 	fseek(_cache, 0, SEEK_END);
 
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, " after SEEK_END, position: %ld\n", ftell(_cache));
+	std::cerr << boost::format(" after SEEK_END, position: %ld") % ftell(_cache) << std::endl;
 #endif
 
 	size_t wrote = fwrite(from, 1, sz, _cache);
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, " write " SIZET_FMT " bytes\n", wrote);
+    std::cerr << boost::format(" write %d bytes") % wrote;
 #endif
 	if ( wrote < 1 )
 	{
-		char errmsg[256];
-	
-		snprintf(errmsg, 255,
-			"writing to cache file: requested " SIZET_FMT ", wrote " SIZET_FMT " (%s)",
-			sz, wrote, strerror(errno));
-		fprintf(stderr, "%s\n", errmsg);
-		throw gnash::GnashException(errmsg);
+        boost::format err = boost::format("writing to cache file: requested %d, wrote %d (%s)")
+            % sz % wrote % std::strerror(errno);
+			
+		std::cerr << err << std::endl;
+		throw IOException(err.str());
 	}
 
 	_cached += sz;
 
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, " after write, position: %ld\n", ftell(_cache));
+    std::cerr << boost::format(" after write, position: %ld") % std::ftell(_cache) << std::endl;
 #endif
 
 	// reset position for next read
 	fseek(_cache, curr_pos, SEEK_SET);
 
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, " after seek-back, position: %ld\n", ftell(_cache));
+    std::cerr << boost::format(" after seek-back, position: %ld") % std::ftell(_cache) << std::endl;
 #endif
 
 	clearerr(_cache);
@@ -203,7 +204,7 @@ void
 NoSeekFile::fill_cache(size_t size)
 {
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, "fill_cache(%d) called\n", size);
+    std::cerr << boost::format(" fill_cache(%d) called") % size << std::endl;
 #endif
 
 	// See how big is the cache
@@ -217,18 +218,16 @@ NoSeekFile::fill_cache(size_t size)
 		bytesNeeded = chunkSize; // why read less ?
 
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-		fprintf(stderr, " bytes needed = " SIZET_FMT "\n", bytesNeeded);
+	std::cerr << boost::format(" bytes needed = %d") % bytesNeeded << std::endl;
 #endif
 
-		ssize_t bytesRead = read(_fd, (void*)_buf, bytesNeeded);
+		ssize_t bytesRead = ::read(_fd, (void*)_buf, bytesNeeded);
 		if ( bytesRead < 0 )
 		{
-			fprintf(stderr,
-				"Error reading " SIZET_FMT " bytes from input stream",
-				bytesNeeded);
+			std::cerr << boost::format(_("Error reading %d bytes from input stream")) % bytesNeeded;
 			_running = false;
 			// this looks like a CRITICAL error (since we don't handle it..)
-			throw gnash::GnashException("Error reading from input stream");
+			throw IOException("Error reading from input stream");
 			return;
 		}
 
@@ -237,7 +236,7 @@ NoSeekFile::fill_cache(size_t size)
 			if ( bytesRead == 0 )
 			{
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-				fprintf(stderr, "EOF reached\n");
+    std::cerr << "EOF reached" << std::endl;
 #endif
 				_running = false;
 				return;
@@ -253,7 +252,7 @@ NoSeekFile::fill_cache(size_t size)
 void
 NoSeekFile::printInfo()
 {
-	fprintf(stderr, "_cache.tell = " SIZET_FMT "\n", tell());
+	std::cerr << "_cache.tell = " << tell() << std::endl;
 }
 
 /*private*/
@@ -265,14 +264,14 @@ NoSeekFile::openCacheFile()
 		_cache = fopen(_cachefilename, "w+b");
 		if ( ! _cache )
 		{
-			throw gnash::GnashException("Could not create cache file " + std::string(_cachefilename));
+			throw IOException("Could not create cache file " + std::string(_cachefilename));
 		}
 	}
 	else
 	{
 		_cache = tmpfile();
 		if ( ! _cache ) {
-			throw gnash::GnashException("Could not create temporary cache file");
+			throw IOException("Could not create temporary cache file");
 		}
 	}
 
@@ -297,17 +296,17 @@ NoSeekFile::~NoSeekFile()
 }
 
 /*public*/
-size_t
-NoSeekFile::read_cache(void *dst, size_t bytes)
+int
+NoSeekFile::read(void *dst, int bytes)
 {
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, "read_cache(%d) called\n", bytes);
+	std::cerr << boost::format("read_cache(%d) called") % bytes << std::endl;
 #endif
 
 	if ( eof() )
 	{
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-		fprintf(stderr, "read_cache: at eof!\n");
+	    std::cerr << "read_cache: at eof!" << std::endl;
 #endif
 		return 0;
 	}
@@ -325,46 +324,45 @@ NoSeekFile::read_cache(void *dst, size_t bytes)
 	{
 		if ( ferror(_cache) )
 		{
-	fprintf(stderr, "an error occurred while reading from cache\n");
+            std::cerr << "an error occurred while reading from cache" << std::endl;
 		}
 #if GNASH_NOSEEK_FD_VERBOSE
 		if ( feof(_cache) )
 		{
-	fprintf(stderr, "EOF reached while reading from cache\n");
+            std::cerr << "EOF reached while reading from cache" << std::endl;
 		}
 #endif
 	}
 
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, "fread from _cache returned " SIZET_FMT "\n", ret);
+    std::cerr << boost::format("fread from _cache returned %d") % ret << std::endl;
 #endif
 
 	return ret;
 
-
 }
 
 /*public*/
 bool
-NoSeekFile::eof()
+NoSeekFile::eof() const
 {
 	bool ret = ( ! _running && feof(_cache) );
 	
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, "eof() returning %d\n", ret);
+	std::cerr << boost::format("eof() returning %d") % ret << std::endl;
 #endif
 	return ret;
 
 }
 
 /*public*/
-size_t
-NoSeekFile::tell()
+int
+NoSeekFile::tell() const
 {
-	long ret =  ftell(_cache);
+	int ret = std::ftell(_cache);
 
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, "tell() returning %ld\n", ret);
+	std::cerr << boost::format("tell() returning %ld") % ret << std::endl;
 #endif
 
 	return ret;
@@ -372,24 +370,23 @@ NoSeekFile::tell()
 }
 
 /*public*/
-bool
-NoSeekFile::seek(size_t pos)
+int
+NoSeekFile::seek(int pos)
 {
 #ifdef GNASH_NOSEEK_FD_WARN_SEEKSBACK
 	if ( pos < tell() ) {
-		fprintf(stderr,
-			"Warning: seek backward requested (%ld from %ld)\n",
-			pos, tell());
+		std::cerr << boost::format("Warning: seek backward requested "
+		                "(%ld from %ld)") % pos % tell() << std::endl;
 	}
 #endif
 
 	fill_cache(pos);
 
-	if ( fseek(_cache, pos, SEEK_SET) == -1 ) {
-		fprintf(stderr, "Warning: fseek failed\n");
-		return false;
+	if ( std::fseek(_cache, pos, SEEK_SET) == -1 ) {
+		std::cerr << "Warning: fseek failed" << std::endl;
+		return -1;
 	} else {
-		return true;
+		return 0;
 	}
 
 }
@@ -400,76 +397,12 @@ NoSeekFile::seek(size_t pos)
  * 
  **********************************************************************/
 
-
-// Return number of bytes actually read.
-static int
-read(void* dst, int bytes, void* appdata)
-{
-	NoSeekFile* stream = (NoSeekFile*) appdata;
-	return stream->read_cache(dst, bytes);
-}
-
-static bool
-eof(void* appdata)
-{
-	NoSeekFile* stream = (NoSeekFile*) appdata;
-	return stream->eof();
-}
-
-static int
-err(void* appdata)
-{
-	NoSeekFile* stream = (NoSeekFile*) appdata;
-	if ( ! stream ) return TU_FILE_OPEN_ERROR;
-	return stream->err();
-}
-
-static int
-write(const void* /*src*/, int /*bytes*/, void* /*appdata*/)
-{
-	abort(); // not supported
-	return 0;
-}
-
-static int
-seek(int pos, void* appdata)
-{
-	NoSeekFile* stream = (NoSeekFile*) appdata;
-	if ( stream->seek(pos) ) return 0;
-	else return TU_FILE_SEEK_ERROR;
-}
-
-static int
-seek_to_end(void* /*appdata*/)
-{
-	abort(); // not supported
-	return 0;
-}
-
-static int
-tell(void* appdata)
-{
-	NoSeekFile* stream = (NoSeekFile*) appdata;
-	return stream->tell();
-}
-
-static int
-close(void* appdata)
-{
-	NoSeekFile* stream = (NoSeekFile*) appdata;
-
-	delete stream;
-
-	//return TU_FILE_CLOSE_ERROR;
-	return 0;
-}
-
 // this is the only exported interface
-tu_file*
+IOChannel*
 make_stream(int fd, const char* cachefilename)
 {
 #ifdef GNASH_NOSEEK_FD_VERBOSE
-	fprintf(stderr, "making NoSeekFile stream for fd %d\n", fd);
+	std::cerr << boost::format("making NoSeekFile stream for fd %d") % fd << std::endl;
 #endif
 
 	NoSeekFile* stream = NULL;
@@ -477,25 +410,16 @@ make_stream(int fd, const char* cachefilename)
 	try {
 		stream = new NoSeekFile(fd, cachefilename);
 	} catch (const std::exception& ex) {
-		fprintf(stderr, "NoSeekFile stream: %s\n", ex.what());
+		std::cerr << boost::format("NoSeekFile stream: %s") % ex.what() << std::endl;
 		delete stream;
 		return NULL;
 	}
 
-	return new tu_file(
-		(void*)stream, // opaque user pointer
-		read, // read
-		write, // write
-		seek, // seek
-		seek_to_end, // seek_to_end
-		tell, // tell
-		eof, // get eof
-		err, // get error
-		NULL, // get stream size
-		close);
+	return stream;
 }
 
-} // namespace noseek_fd_adapter
+} // namespace gnash::noseek_fd_adapter
+} // namespace gnash
 
 
 
