@@ -15,36 +15,39 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-/* $Id: noseek_fd_adapter.h,v 1.7 2008/01/21 20:55:45 rsavoye Exp $ */
 
 #ifndef STDIN_ADAPTER_H
 #define STDIN_ADAPTER_H
 
-#include "tu_config.h"
+#include "dsodefs.h"
 
 #include <string>
 
 
-class tu_file;
+namespace gnash {
+class IOChannel;
 
 
-/// Code to use volatile (non-back-seekable) streams as tu_files
-/// by storing read bytes in a temporary file.
+/// Code to use volatile (non-back-seekable) streams as IOChannel
+/// objects (which are seekable by definition) by storing read bytes
+/// in a temporary file.
 namespace noseek_fd_adapter
 {
 
 /// \brief
-/// Returns a read-only tu_file stream that fetches data
+/// Returns a read-only IOChannel that fetches data
 /// from an file descriptor open for read.
 //
-/// The caller owns the returned tu_file*.  
+/// The caller owns the returned IOChannel.  
 ///
 /// Specify a cachefilename if you want to be able to access
-/// the full cache after deletion of the returned tu_file.
+/// the full cache after deletion of the returned IOChannel.
 ///
-DSOEXPORT tu_file* make_stream(int fd, const char* cachefilename=NULL);
+DSOEXPORT IOChannel* make_stream(int fd, const char* cachefilename=NULL);
 
-}
+} // namespace gnash::noseek_fd_adapter
+} // namespace gnash
+ 
 
 #endif // STDIN_ADAPTER_H
 
