@@ -20,6 +20,9 @@
 #include "gnashconfig.h"
 #endif
 
+#include <boost/thread/mutex.hpp>
+
+
 #include "utility.h"
 #include "log.h"
 #include "network.h"
@@ -48,6 +51,8 @@
 # include <sys/select.h>
 #endif
 
+#include "buffer.h"
+
 #ifndef MAXHOSTNAMELEN
 #define MAXHOSTNAMELEN 256
 #endif
@@ -473,6 +478,7 @@ Network::createClient(const string &hostname, short port)
         return false;
     }
 
+    _port = port;    
     log_debug(_("%s: to host %s at port %d"), __FUNCTION__, hostname, port);
 
     memset(&sock_in, 0, sizeof(struct sockaddr_in));
@@ -580,6 +586,7 @@ Network::createClient(const string &hostname, short port)
 #endif
 
     _connected = true;
+    _port = port;
     assert(_sockfd > 0);
     return true;
 }
@@ -678,32 +685,69 @@ Network::closeConnection(int fd)
     return false;
 }
 
+amf::Buffer *
+Network::readNet()
+{
+//    GNASH_REPORT_FUNCTION;
+
+    amf::Buffer *buffer = new amf::Buffer;
+    int nbytes = readNet(buffer);
+    if (nbytes > 0) {
+	buffer->resize(nbytes);
+	return buffer;
+    }
+
+    return 0;
+}
+
 // Read from the connection
+int
+Network::readNet(amf::Buffer *buffer)
+{
+//    GNASH_REPORT_FUNCTION;
+    return readNet(_sockfd, buffer->reference(), buffer->size(), _timeout);
+}
+
+int
+Network::readNet(amf::Buffer *buffer, int timeout)
+{
+//    GNASH_REPORT_FUNCTION;
+    return readNet(_sockfd, buffer->reference(), buffer->size(), timeout);
+}
+
 int
 Network::readNet(byte_t *buffer, int nbytes)
 {
+//    GNASH_REPORT_FUNCTION;
     return readNet(_sockfd, buffer, nbytes, _timeout);
 }
 
 int
 Network::readNet(byte_t *buffer, int nbytes, int timeout)
 {
+//    GNASH_REPORT_FUNCTION;
     return readNet(_sockfd, buffer, nbytes, timeout);
 }
 
 int
 Network::readNet(int fd, byte_t *buffer, int nbytes)
 {
+//    GNASH_REPORT_FUNCTION;
     return readNet(fd, buffer, nbytes, _timeout);
 }
 
 int
 Network::readNet(int fd, byte_t *buffer, int nbytes, int timeout)
 {
+//    GNASH_REPORT_FUNCTION;
+
     fd_set              fdset;
     int                 ret = -1;
     struct timeval      tval;
 
+    if (_debug) {
+	log_debug (_("Trying to read %d bytes from fd #%d"), nbytes, fd);
+    }
 #ifdef NET_TIMING
     if (_timing_debug)
     {
@@ -763,6 +807,12 @@ Network::readNet(int fd, byte_t *buffer, int nbytes, int timeout)
 }
 
 // Write to the connection
+int
+Network::writeNet(amf::Buffer *buffer)
+{
+    return writeNet(buffer->reference(), buffer->size());
+};
+
 int
 Network::writeNet(const std::string& buffer)
 {
