@@ -1,9 +1,9 @@
 // 
-//   Copyright (C) 2005, 2006, 2007 Free Software Foundation, Inc.
+//   Copyright (C) 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 // 
 // This program is distributed in the hope that it will be useful,
@@ -16,12 +16,6 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
-
-/*
- *  npapi.h $Revision: 1.6 $
- *  Netscape client plug-in API spec
- */
-
 #ifndef _NPAPI_H_
 #define _NPAPI_H_
 
@@ -32,7 +26,6 @@
 #include "prtypes.h"
 /* Copied from xp_core.h */
 /* removed #ifdef for hpux defined in /usr/include/model.h */
-#ifndef XP_MAC
 #ifndef _INT16
 #define _INT16
 #endif
@@ -45,7 +38,6 @@
 #ifndef _UINT32
 #define _UINT32
 #endif
-#endif
 
 /* 
  * NO_NSPR_10_SUPPORT disables the inclusion 
@@ -75,11 +67,6 @@
 
 #ifdef __MWERKS__
 #	define _declspec __declspec
-#	ifdef macintosh
-#		ifndef XP_MAC
-#			define XP_MAC 1
-#		endif /* XP_MAC */
-#	endif /* macintosh */
 #	ifdef __INTEL__
 #		undef NULL
 #		ifndef XP_WIN
@@ -88,13 +75,15 @@
 #	endif /* __INTEL__ */
 #endif /* __MWERKS__ */
 
-#if defined(XP_MAC) || defined(XP_MACOSX)
-	#include <Quickdraw.h>
-	#include <Events.h>
+#ifdef XP_MACOSX
+#include <Carbon/Carbon.h>
+#ifdef __LP64__
+#define NP_NO_QUICKDRAW
+#endif
 #endif
 
 #if defined(XP_UNIX) 
-#	include <cstdio>
+#	include <stdio.h>
 #	if defined(MOZ_X11)
 #		include <X11/Xlib.h>
 #		include <X11/Xutil.h>
@@ -106,7 +95,7 @@
 /*----------------------------------------------------------------------*/
 
 #define NP_VERSION_MAJOR 0
-#define NP_VERSION_MINOR 14
+#define NP_VERSION_MINOR 19
 
 
 /* The OS/2 version of Netscape uses RC_DATA to define the
@@ -201,6 +190,15 @@ typedef long int32;
 #define NULL (0L)
 #endif
 
+#ifdef XP_MACOSX
+typedef enum {
+#ifndef NP_NO_QUICKDRAW
+  NPDrawingModelQuickDraw = 0,
+#endif
+  NPDrawingModelCoreGraphics = 1
+} NPDrawingModel;
+#endif
+
 typedef unsigned char	NPBool;
 typedef int16			NPError;
 typedef int16			NPReason;
@@ -212,10 +210,6 @@ typedef char*			NPMIMEType;
 /*                       Structures and definitions                     */
 /*----------------------------------------------------------------------*/
 
-#ifdef XP_MAC
-#pragma options align=mac68k
-#endif
-
 /*
  *  NPP is a plug-in's opaque instance handle
  */
@@ -236,6 +230,16 @@ typedef struct _NPStream
   uint32 end;
   uint32 lastmodified;
   void*  notifyData;
+  const  char* headers; /* Response headers from host.
+                         * Exists only for >= NPVERS_HAS_RESPONSE_HEADERS.
+                         * Used for HTTP only; NULL for non-HTTP.
+                         * Available from NPP_NewStream onwards.
+                         * Plugin should copy this data before storing it.
+                         * Includes HTTP status line and all headers,
+                         * preferably verbatim as received from server,
+                         * headers formatted as in HTTP ("Header: Value"),
+                         * and newlines (\n, NOT \r\n) separating lines.
+                         * Terminated by \n\0 (NOT \n\n\0). */
 } NPStream;
 
 
@@ -371,9 +375,22 @@ typedef enum {
   /* Introduced in Mozilla 1.0 */
   NPPVpluginKeepLibraryInMemory = 13,
   NPPVpluginNeedsXEmbed         = 14,
-  
-  /* Get the NPObject for scripting the plugin. */
-  NPPVpluginScriptableNPObject  = 15
+
+  /* Get the NPObject for scripting the plugin. Introduced in Firefox
+   * 1.0 (NPAPI minor version 14).
+   */
+  NPPVpluginScriptableNPObject  = 15,
+
+  /* Get the plugin value (as \0-terminated UTF-8 string data) for
+   * form submission if the plugin is part of a form. Use
+   * NPN_MemAlloc() to allocate memory for the string data. Introduced
+   * in Mozilla 1.8b2 (NPAPI minor version 15).
+   */
+  NPPVformValue = 16
+#ifdef XP_MACOSX
+  /* Used for negotiating drawing models */
+  , NPPVpluginDrawingModel = 1000
+#endif
 } NPPVariable;
 
 /*
@@ -398,7 +415,18 @@ typedef enum {
   NPNVWindowNPObject = 15,
 
   /* Get the NPObject wrapper for the plugins DOM element. */
-  NPNVPluginElementNPObject = 16
+  NPNVPluginElementNPObject = 16,
+
+  NPNVSupportsWindowless = 17
+
+#ifdef XP_MACOSX
+  /* Used for negotiating drawing models */
+  , NPNVpluginDrawingModel = 1000
+#ifndef NP_NO_QUICKDRAW
+  , NPNVsupportsQuickDrawBool = 2000
+#endif
+  , NPNVsupportsCoreGraphicsBool = 2001
+#endif
 } NPNVariable;
 
 /*
@@ -459,7 +487,7 @@ typedef struct _NPPrint
   } print;
 } NPPrint;
 
-#if defined(XP_MAC) || defined(XP_MACOSX)
+#ifdef XP_MACOSX
 typedef EventRecord	NPEvent;
 #elif defined(XP_WIN)
 typedef struct _NPEvent
@@ -479,19 +507,23 @@ typedef struct _NPEvent
 typedef XEvent NPEvent;
 #else
 typedef void*			NPEvent;
-#endif /* XP_MAC */
+#endif /* XP_MACOSX */
 
-#if defined(XP_MAC) || defined(XP_MACOSX)
-typedef RgnHandle NPRegion;
+#ifdef XP_MACOSX
+typedef void* NPRegion;
+#ifndef NP_NO_QUICKDRAW
+typedef RgnHandle NPQDRegion;
+#endif
+typedef CGPathRef NPCGRegion;
 #elif defined(XP_WIN)
 typedef HRGN NPRegion;
 #elif defined(XP_UNIX) && defined(MOZ_X11)
 typedef Region NPRegion;
 #else
 typedef void *NPRegion;
-#endif /* XP_MAC */
+#endif /* XP_MACOSX */
 
-#if defined(XP_MAC) || defined(XP_MACOSX)
+#ifdef XP_MACOSX
 /*
  *  Mac-specific structures and definitions.
  */
@@ -503,6 +535,12 @@ typedef struct NP_Port
   int32 porty;
 } NP_Port;
 
+typedef struct NP_CGContext
+{
+  CGContextRef context;
+  WindowRef window;
+} NP_CGContext;
+
 /*
  *  Non-standard event types that can be passed to HandleEvent
  */
@@ -522,7 +560,7 @@ enum NPEventType {
 #define loseFocusEvent    (osEvt + 17)
 #define adjustCursorEvent (osEvt + 18)
 #endif
-#endif /* XP_MAC */
+#endif /* XP_MACOSX */
 
 /*
  * Values for mode passed to NPP_New:
@@ -540,10 +578,6 @@ enum NPEventType {
 
 #define NP_MAXREADY	(((unsigned)(~0)<<1)>>1)
 
-#ifdef XP_MAC
-#pragma options align=reset
-#endif
-
 
 /*----------------------------------------------------------------------*/
 /*		     Error and Reason Code definitions			*/
@@ -586,13 +620,19 @@ enum NPEventType {
 /*
  * Version feature information
  */
-#define NPVERS_HAS_STREAMOUTPUT      8
-#define NPVERS_HAS_NOTIFICATION      9
-#define NPVERS_HAS_LIVECONNECT       9
-#define NPVERS_WIN16_HAS_LIVECONNECT 9
-#define NPVERS_68K_HAS_LIVECONNECT   11
-#define NPVERS_HAS_WINDOWLESS        11
-#define NPVERS_HAS_XPCONNECT_SCRIPTING 13
+#define NPVERS_HAS_STREAMOUTPUT             8
+#define NPVERS_HAS_NOTIFICATION             9
+#define NPVERS_HAS_LIVECONNECT              9
+#define NPVERS_WIN16_HAS_LIVECONNECT        9
+#define NPVERS_68K_HAS_LIVECONNECT          11
+#define NPVERS_HAS_WINDOWLESS               11
+#define NPVERS_HAS_XPCONNECT_SCRIPTING      13
+#define NPVERS_HAS_NPRUNTIME_SCRIPTING      14
+#define NPVERS_HAS_FORM_VALUES              15
+#define NPVERS_HAS_POPUPS_ENABLED_STATE     16
+#define NPVERS_HAS_RESPONSE_HEADERS         17
+#define NPVERS_HAS_NPOBJECT_ENUM            18
+#define NPVERS_HAS_PLUGIN_THREAD_ASYNC_CALL 19
 
 /*----------------------------------------------------------------------*/
 /*                        Function Prototypes                           */
@@ -645,9 +685,6 @@ void    NP_LOADDS NPP_URLNotify(NPP instance, const char* url,
 jref    NP_LOADDS NPP_GetJavaClass(void);
 #endif
 NPError NP_LOADDS NPP_GetValue(NPP instance, NPPVariable variable, void *value);
-/*
- * Uh, shouldn't NPP_SetValue() take an NPPVariable and not an NPNVariable?
- */
 NPError NP_LOADDS NPP_SetValue(NPP instance, NPNVariable variable, void *value);
 
 /*
@@ -686,6 +723,11 @@ NPError NP_LOADDS NPN_SetValue(NPP instance, NPPVariable variable, void *value);
 void    NP_LOADDS NPN_InvalidateRect(NPP instance, NPRect *invalidRect);
 void    NP_LOADDS NPN_InvalidateRegion(NPP instance, NPRegion invalidRegion);
 void    NP_LOADDS NPN_ForceRedraw(NPP instance);
+void    NP_LOADDS NPN_PushPopupsEnabledState(NPP instance, NPBool enabled);
+void    NP_LOADDS NPN_PopPopupsEnabledState(NPP instance);
+void    NP_LOADDS NPN_PluginThreadAsyncCall(NPP instance,
+                                            void (*func) (void *),
+                                            void *userData);
 
 #ifdef __cplusplus
 }  /* end extern "C" */
