@@ -1,5 +1,5 @@
 /* 
- *   Copyright (C) 2005, 2006, 2007 Free Software Foundation, Inc.
+ *   Copyright (C) 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,8 +23,7 @@
 #include "MovieTester.h"
 #include "sprite_instance.h"
 #include "character.h"
-#include "dlist.h"
-#include "container.h"
+#include "DisplayList.h"
 #include "log.h"
 
 #include "check.h"
@@ -43,7 +42,7 @@ main(int /*argc*/, char** /*argv*/)
 	sprite_instance* root = tester.getRootMovie();
 	assert(root);
 
-	check_equals(root->get_frame_count(), 8);
+	check_equals(root->get_frame_count(), 14);
 	check_equals(root->get_play_state(), sprite_instance::PLAY);
 	check_equals(root->get_current_frame(), 0);
 
