@@ -1,5 +1,5 @@
 /* 
- *   Copyright (C) 2007 Free Software Foundation, Inc.
+ *   Copyright (C) 2007, 2008 Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 
 const char* mediadir=".";
 char filename[256];
+char filename2[256];
 
 
 int
@@ -49,7 +50,7 @@ main(int argc, char** argv)
   SWFAction a;
   SWFAction b;
   char buffer_a[1028];
-  char buffer_b[1028];
+  char buffer_b[2048];
 
   int video_width = 128;
   int video_height = 96;
@@ -62,6 +63,7 @@ main(int argc, char** argv)
   }
 	
   sprintf(filename, "%s/square.flv", mediadir);
+  sprintf(filename2, "%s/square.ogg", mediadir);
 
   // Some online examples...
   //
@@ -79,9 +81,10 @@ main(int argc, char** argv)
   sprintf(buffer_a,
   	"note(System.capabilities.version);"
   	"note('SWF version %d');"
-  	
   	"nc=new NetConnection();"
+	"check(!nc.isConnected, 'newly created NetConnection is not connected');"
 	"nc.connect(null);"
+	"xcheck(nc.isConnected, 'NetConnection is connected after .connect(null)');"
 	"check(!NetStream.prototype.hasOwnProperty('currentFPS'));" // version 7 here
 	"xcheck(!NetStream.prototype.hasOwnProperty('currentFps'));"
 	"stream = new NetStream();"
@@ -90,14 +93,81 @@ main(int argc, char** argv)
 	"stream = new NetStream(nc);"
 	"check_equals ( typeof(stream.bytesTotal), 'number' );"
 	"stream.bytesTotal = 'string';"
-	"check_equals ( typeof(stream.bytesTotal), 'number' );",	
-	OUTPUT_VERSION);
+	"check_equals ( typeof(stream.bytesTotal), 'number' );"
+	"stream2 = new NetStream(nc);"
+	, OUTPUT_VERSION);
 
-  	sprintf(buffer_b,
+  sprintf(buffer_b,
   	// bytesTotal (read-only)
+	"MovieClip.prototype.addBytesLoadedProgress = function(v, s) {"
+	"	var nam = 'blprogress_'+v;"
+	"	var dep = this.getNextHighestDepth();"
+	"	var pc = this.createEmptyMovieClip(nam, dep);"
+	"	pc.stream = s;"
+	"	pc.video = v;"
+	"	var pcp = pc.createEmptyMovieClip('bar', pc.getNextHighestDepth());"
+	"	var x = v._x;"
+	"	var y = v._y+v._height+10;"
+	"	var w = v._width;"
+	"	var h = 10;"
+	"	with(pcp) {"
+	"		_x = x;"
+	"		_y = y;"
+	"		moveTo(0,0);"
+	"		beginFill(0xFF0000,50);"
+	"		lineTo(0, h);"
+	"		lineTo(w, h);"
+	"		lineTo(w, 0);"
+	"		lineTo(0, 0);"
+	"		endFill();"
+	"	};"
+	"	pc.onEnterFrame = function() {"
+	"		pcp._xscale = 100*(this.stream.bytesLoaded/this.stream.bytesTotal);"
+	"	};"
+	"};"
+	"MovieClip.prototype.addBufferLoadedProgress = function(v, s) {"
+	"	var nam = 'blprogress_'+v;"
+	"	var dep = this.getNextHighestDepth();"
+	"	var pc = this.createEmptyMovieClip(nam, dep);"
+	"	pc.stream = s;"
+	"	pc.video = v;"
+	"	var pcp = pc.createEmptyMovieClip('bar', pc.getNextHighestDepth());"
+	"	var x = v._x;"
+	"	var y = v._y+v._height+22;"
+	"	var w = v._width;"
+	"	var h = 10;"
+	"	with(pcp) {"
+	"		_x = x;"
+	"		_y = y;"
+	"		moveTo(0,0);"
+	"		beginFill(0x00FF00,50);"
+	"		lineTo(0, h);"
+	"		lineTo(w, h);"
+	"		lineTo(w, 0);"
+	"		lineTo(0, 0);"
+	"		endFill();"
+	"	};"
+	"	pc.onEnterFrame = function() {"
+	//"		_root.note(this.video._x+': bufferloaded: '+this.stream.bufferLength+'/'+this.stream.bufferTime);"
+	"		pcp._xscale = 100*(this.stream.bufferLength/this.stream.bufferTime);"
+	// 		when bufferLength > bufferTime (common):
+	"		if ( pcp._xscale > 100 ) {"
+	"			pcp._xscale = 100;"
+	"			pcp._alpha = 100;"
+	"		} else {"
+	"			pcp._alpha = 50;"
+	"		}"
+	"	};"
+	"};"
 	"stream.play('%s');"
+	"stream2.play('%s');"
+	"stream.pause(true);" 
+	"stream.paused=true;"
+	"_root.metadataNotified=0;"
+	"_root.startNotified=0;"
+	"_root.stopNotified=0;"
 	"stop();",
-	filename);
+	filename, filename2);
 
   Ming_init();
   Ming_useSWFVersion (OUTPUT_VERSION);
@@ -123,6 +193,12 @@ main(int argc, char** argv)
   /* SWFDisplayItem_moveTo(item, 0, 200); */
   SWFDisplayItem_setName(item, "video");
 
+  stream = newSWFVideoStream();
+  SWFVideoStream_setDimension(stream, video_width, video_height);
+  item = SWFMovie_add(mo, (SWFBlock)stream);
+  SWFDisplayItem_moveTo(item, 400, 0);
+  SWFDisplayItem_setName(item, "video2");
+
   a = newSWFAction(buffer_a);
   if(a == NULL) return -1;
   SWFMovie_add(mo, (SWFBlock)a);
@@ -138,8 +214,91 @@ main(int argc, char** argv)
   check(mo, "NetStream.prototype.hasOwnProperty('time')"); // check time
   check(mo, "NetStream.prototype.hasOwnProperty('bytesLoaded')"); // check bytesLoaded
   check(mo, "NetStream.prototype.hasOwnProperty('bytesTotal')"); // check bytesTotal
+
+  //-----------------------------------------
+  // Dynamic volume tests using Sound object
+  //-----------------------------------------
+
+  // create a movieclip to use as sound controller
+  add_actions(mo, "createEmptyMovieClip('dv1', 1);");
+
+  // attach Sound s1 to character dv1
+  add_actions(mo, "s1 = new Sound(dv1);");
+  // Sound.getVolume fetches volume from dv1 (see s2 below)
+  check_equals(mo, "s1.getVolume()", "100");
+
+  // Change volume of Sound s1 (will change volume of attached character, see below)
+  add_actions(mo, "s1.setVolume(1000);");
+  check_equals(mo, "s1.getVolume()", "1000"); 
+
+  // attach Sound s2 to character dv2
+  add_actions(mo, "s2 = new Sound(dv1);");
+  // Sound s2 finds volume of dv1 being 1000
+  check_equals(mo, "s2.getVolume()", "1000");
+
+  // This shows that setVolume/getVolume make callbacks
+  // to attached character as changing volume of one Sound
+  // influence the other attached sound...
+  add_actions(mo, "s2.setVolume(5);");
+  check_equals(mo, "s2.getVolume()", "5"); 
+  check_equals(mo, "s1.getVolume()", "5"); 
+  add_actions(mo, "s1.setVolume(80);");
+  check_equals(mo, "s2.getVolume()", "80"); 
+  check_equals(mo, "s1.getVolume()", "80");
+  // btw, negative volume is fine..
+  add_actions(mo, "s1.setVolume(-20);");
+  check_equals(mo, "s2.getVolume()", "-20"); 
+  check_equals(mo, "s1.getVolume()", "-20");
+
+  // If the attached-to character gets unloaded,
+  // getVolume returns undefined...
+  add_actions(mo, "dv1.removeMovieClip();");
+  check_equals(mo, "typeof(s2.getVolume())", "'undefined'"); 
+  check_equals(mo, "typeof(s1.getVolume())", "'undefined'");
+  // even if you reset it explicitly
+  add_actions(mo, "s2.setVolume(50);");
+  check_equals(mo, "typeof(s2.getVolume())", "'undefined'"); 
+  check_equals(mo, "typeof(s1.getVolume())", "'undefined'");
+  // but you get it back when you create a replacement..
+  add_actions(mo, "createEmptyMovieClip('dv1', 2);");
+  check_equals(mo, "s2.getVolume()", "100"); 
+  check_equals(mo, "s1.getVolume()", "100");
+  add_actions(mo, "s1.setVolume(80);");
+  check_equals(mo, "s2.getVolume()", "80"); 
+  check_equals(mo, "s1.getVolume()", "80");
+
+  // And you can attach a Sound to any character, not
+  // just MovieClip ones.
+  // This is against a video instance
+  add_actions(mo, "s1 = new Sound(video); s2 = new Sound(video);");
+  check_equals(mo, "s2.getVolume()", "100"); 
+  check_equals(mo, "s1.getVolume()", "100");
+  add_actions(mo, "s1.setVolume(80);");
+  check_equals(mo, "s2.getVolume()", "80"); 
+  check_equals(mo, "s1.getVolume()", "80");
+
+  // Here's a 3 level volume controller. Our square.flv doesn't have sound
+  // so you can't really see if it's working or not... Anyway, change
+  // the code to load a movie with sound and see what happens changing the volumes
+  // below
+  add_actions(mo, 
+		"dv1.createEmptyMovieClip('dv2', 1);"
+		"dv1.dv2.createEmptyMovieClip('dv3', 1);"
+                "dv1.dv2.dv3.attachAudio(stream);" // attach stream to 3rd level
+                "s1 = new Sound(dv1);"
+                "s2 = new Sound(dv1.dv2);"
+                "s3 = new Sound(dv1.dv2.dv3);"
+		"s3.setVolume(50);" // ---------- level1 volume (change me for tests)
+		"s1.setVolume(50);" // ---------- level2 volume (change me for tests)
+		"s2.setVolume(400);" // --------- level3 volume (change me for tests)
+                );
+
+  //------------------------------------------
+  // Now attach video to the video characters
+  //------------------------------------------
   
   add_actions(mo, "video.attachVideo(stream);"); 
+  add_actions(mo, "video2.attachVideo(stream2);"); 
   
   // currentFps (read-only)
   check_equals (mo, "typeof(stream.currentFps)", "'number'" );
@@ -222,7 +381,12 @@ main(int argc, char** argv)
 		"video._x = 100;"
 		"video._xscale = 120;"
 		"video._yscale = 120;"
-		"video._rotation = 45;");
+		"video._rotation = 45;"
+		"_root.addBytesLoadedProgress(video, stream);"
+		"_root.addBytesLoadedProgress(video2, stream2);"
+		"_root.addBufferLoadedProgress(video, stream);"
+		"_root.addBufferLoadedProgress(video2, stream2);"
+	);
 
   check_equals(mo, "video._x", "100")	;
   check_equals(mo, "Math.round(video._xscale*100)/100", "120");
@@ -236,6 +400,29 @@ main(int argc, char** argv)
 
   SWFMovie_add(mo, (SWFBlock)newSWFAction(
 
+		"_root.onKeyDown = function() {"
+		" 	_root.note(' bufferLength:'+stream.bufferLength+"
+		" 		' bytesLoaded:'+stream.bytesLoaded+"
+		"		' currentFps:'+stream.currentFps+' time:'+stream.time);"
+		"	var ascii = Key.getAscii();"
+		"	trace('Key down: '+ascii);"
+		"	if ( ascii == 32 ) {" // ' ' - pause(toggle)
+		"		stream.paused = !stream.paused;"
+		"		stream.pause();" // stream.paused);"
+		"	}"
+		"	else if ( ascii == 112 ) {" // 'p' - play()
+		"		stream.play();"
+		"               _root.note(\"2. Verify video hasn't started, then press space to continue.\");"
+		"	}"
+		"	else if ( ascii == 99 ) {" // 'c' - play()
+		"		_root.check(nc.isConnected, 'NetConnection is connected');"
+		"		_root.nc.close();"
+		"               _root.note(\"Closed netconnection\");"
+		"		_root.check(!nc.isConnected, 'NetConnection is not connected');"
+		"	}"
+		"};"
+		"Key.addListener(_root);"
+
 		"stream.onStatus = function(info) {"
 
 		"  if ( ! _root.enumerableStatusInfoChecked ) {"
@@ -265,17 +452,26 @@ main(int argc, char** argv)
 
 		// Print some info
 		" _root.note('onStatus('+info.code+') called'); "
-		" _root.note(' bufferLength:'+stream.bufferLength+"
-		" 	' bytesLoaded:'+stream.bytesLoaded+"
-		"	' currentFps:'+stream.currentFps+' time:'+stream.time);"
 
-		" if ( info.code == 'NetStream.Play.Stop' )"
+		" if ( info.code == 'NetStream.Play.Start' )"
 		" {"
-		" 	_root.check(this instanceOf NetStream); "
-		" 	_root.check_equals(this.bufferTime, 2); "
-		" 	_root.check_equals(this.bytesTotal, 21482); "
-		"	this.stopNotified = true;"
-		"	_root.nextFrame();"
+		"	check(!_root.startNotified, 'No duplicated Play.Start notification');"
+		"	_root.startNotified++;"
+		" }"
+
+		" else if ( info.code == 'NetStream.Play.Stop' )"
+		" {"
+		" 	if ( ! _root.stopNotified )"
+		" 	{"
+		" 		_root.stopNotified++;"
+		" 		stream.seek(0);"
+		" 	} else {"
+		"		_root.stopNotified++;"
+		" 		_root.check(this instanceOf NetStream); "
+		" 		_root.check_equals(this.bufferTime, 2); "
+		" 		_root.check_equals(this.bytesTotal, 21482); "
+		"		_root.nextFrame();"
+		"	}"
 		" }"
 #if 0
 		" else if ( info.code == 'NetStream.Buffer.Empty' && this.stopNotified ) "
@@ -302,21 +498,33 @@ main(int argc, char** argv)
 		" }"
 		" _root.note('onMetaData: '+s);"
 
+
+		" _root.metadataNotified++;"
+
+		// don't run other tests if already done
+		// BTW: should be called once, gnash (gst) calls this twice
+		//      and would succeed in composition checking in second call.
+		" if ( _root.metadataNotified > 1 ) return;"
+
+		" check(_root.startNotified, 'onMetaData should be notified after Play.Start');"
 		" check_equals(arguments.length, 1, 'single argument');"
-		" check(info instanceof Object);"
+		" check(info instanceof Array, 'onMetaData argument sent from square.flv should be instanceof Array');"
+		" check_equals(info.length, 11);" // it's an array so we can check length. gnash fails by discarding the count element of ECMA_ARRAY AMF type
 
 		// Test enumeration
 		" var enu = new Array;"
 		" for (e in info) { "
 		"  enu.push(e);"
 		" }"
-		" xcheck_equals(enu.length, 11);" // gnash contains 2 more 
+		" check_equals(enu.length, 11);" // this is actual (not virtual) composition
 
 		"\n"
 
 
 		// Test composision
 
+		" check(info.hasOwnProperty('length'), 'metadata has length');" // it's an array...
+
 		" check(info.hasOwnProperty('filesize'), 'metadata has filesize');"
 		" check_equals(typeof(info.filesize), 'number', 'filesize is a number');"
 		" check_equals(info.filesize, '21482', 'actual filesize');"
@@ -397,12 +605,17 @@ main(int argc, char** argv)
 		" delete info.duration;"
 		" check(!info.hasOwnProperty('duration'), 'metadata duration can be deleted');"
 
+		" _root.note('1. Press \"p\" key');"
+
 		"};"
 		));
 
   SWFMovie_nextFrame(mo);
 
-  SWFMovie_add(mo, (SWFBlock)newSWFAction("totals(112); stop();"));
+  check_equals(mo, "metadataNotified", "1");
+  check_equals(mo, "stopNotified", "2");
+  check_equals(mo, "startNotified", "1");
+  SWFMovie_add(mo, (SWFBlock)newSWFAction("totals(142); stop(); end_of_test=true;"));
 
   SWFMovie_nextFrame(mo);
 
