@@ -21,9 +21,11 @@
 #define INPUT_FILENAME "NetStream-SquareTest.swf"
 
 #include "MovieTester.h"
+#include "VM.h"
+#include "string_table.h"
 #include "sprite_instance.h"
 #include "character.h"
-#include "dlist.h"
+#include "DisplayList.h"
 #include "log.h"
 
 #include "check.h"
@@ -62,15 +64,38 @@ main(int /*argc*/, char** /*argv*/)
 	// When all possible tests are implemented as self-contained, we'll
 	// add tests that can't be self-contained.
 	//
-	while (root->get_current_frame() < 2)
+	string_table& st = VM::get().getStringTable();
+	string_table::key k = st.find("startNotified");
+	as_value tmp;
+	while (! root->get_member(k, &tmp) )
+	{
+		tester.advance();
+
+		// sleep to give the NetStream a chance to load
+        // data and trigger notifications
+		// needs more analisys to find a good way for doing this..
+        // TODO: sleep less ! GnashSleep !
+		sleep(1);
+	}
+
+	cout << "Pressing space" << endl;
+	tester.pressKey(key::SPACE);
+	tester.releaseKey(key::SPACE);
+
+    while (root->get_current_frame() < 2)
 	{
 		tester.advance();
 
 		// sleep to give the NetStream a chance to load data and trigger notifications
 		// needs more analisys to find a good way for doing this..
+        // TODO: sleep less !!
 		sleep(1);
 	}
 
+	// Consistency check 
+	as_value eot;
+	bool endOfTestFound = root->get_member(st.find("end_of_test"), &eot);
+	check(endOfTestFound);
 
 }
 
