@@ -18,12 +18,12 @@
  *
  */ 
 
-#define INPUT_FILENAME "ButtonEventsTest.swf"
+#define INPUT_FILENAME "SpriteButtonEventsTest.swf"
 
 #include "MovieTester.h"
 #include "sprite_instance.h"
 #include "character.h"
-#include "dlist.h"
+#include "DisplayList.h"
 #include "log.h"
 
 #include "check.h"
@@ -42,19 +42,23 @@ test_mouse_activity(MovieTester& tester, const character* text, const character*
 	rgba covered_yellow(128,255,0,255); // yellow, covered by 50% black
 	rgba green(0,255,0,255);
 
+	string tmp, tmp2; // to backup text and text2 values before changing them
+
 	// roll over the middle of the square, this should change
 	// the textfield value, if enabled
+	tmp = text->get_text_value();
+	tmp2 = text2->get_text_value();
 	tester.movePointerTo(60, 60);
 	if ( enabled ) {
-		check_equals(string(text->get_text_value()), string("MouseOver"));
-		check_equals(string(text2->get_text_value()), string("RollOver"));
+		check_equals(string(text->get_text_value()), string("RollOver"));
+		check_equals(string(text2->get_text_value()), tmp2); // would retain last value
 		check(tester.isMouseOverMouseEntity());
 		// check that pixel @ 60,60 is yellow !
 		if ( covered ) { check_pixel(60, 60, 2, covered_yellow, 2);  }
 		else { check_pixel(60, 60, 2, yellow, 2);  }
 	} else {
-		check_equals(string(text->get_text_value()), string("MouseOut"));
-		check_equals(string(text2->get_text_value()), string("RollOut"));
+		check_equals(string(text->get_text_value()), tmp); // not enabled...
+		check_equals(string(text2->get_text_value()), tmp2); // would retain last value
 		check(!tester.isMouseOverMouseEntity());
 		// check that pixel @ 60,60 is red !
 		if ( covered ) { check_pixel(60, 60, 2, covered_red, 2);  }
@@ -65,15 +69,15 @@ test_mouse_activity(MovieTester& tester, const character* text, const character*
 	// the textfield value, if enabled.
 	tester.pressMouseButton();
 	if ( enabled ) {
-		check_equals(string(text->get_text_value()), string("MouseDown"));
-		check_equals(string(text2->get_text_value()), string("Press"));
+		check_equals(string(text->get_text_value()), string("Press"));
+		check_equals(string(text2->get_text_value()), string("MouseDown"));
 		check(tester.isMouseOverMouseEntity());
 		// check that pixel @ 60,60 is green !
 		check_pixel(60, 60, 2, green, 2);
 	} else {
-		check_equals(string(text->get_text_value()), string("MouseOut"));
-		check_equals(string(text2->get_text_value()), string("RollOut"));
-		check(!tester.isMouseOverMouseEntity());
+		check_equals(string(text->get_text_value()), tmp); 
+		check_equals(string(text2->get_text_value()), string("MouseDown")); // no matter .enabled
+		check(!tester.isMouseOverMouseEntity()); 
 		// check that pixel @ 60,60 is red !
 		if ( covered ) { check_pixel(60, 60, 2, covered_red, 2);  }
 		else { check_pixel(60, 60, 2, red, 2);  }
@@ -83,36 +87,47 @@ test_mouse_activity(MovieTester& tester, const character* text, const character*
 	// the textfield value, if enabled
 	tester.depressMouseButton();
 	if ( enabled ) {
-		check_equals(string(text->get_text_value()), string("MouseUp"));
-		check_equals(string(text2->get_text_value()), string("Release"));
+		check_equals(string(text->get_text_value()), string("Release"));
+		check_equals(string(text2->get_text_value()), string("MouseUp"));
 		check(tester.isMouseOverMouseEntity());
 		// check that pixel @ 60,60 is yellow !
 		if ( covered ) { check_pixel(60, 60, 2, covered_yellow, 2);  }
 		else { check_pixel(60, 60, 2, yellow, 2);  }
 	} else {
-		check_equals(string(text->get_text_value()), string("MouseOut"));
-		check_equals(string(text2->get_text_value()), string("RollOut"));
-		check(!tester.isMouseOverMouseEntity());
+		check_equals(string(text->get_text_value()), tmp);
+		check_equals(string(text2->get_text_value()), string("MouseUp")); // no matter .enabled
+		check(!tester.isMouseOverMouseEntity()); 
 		// check that pixel @ 60,60 is red !
 		if ( covered ) { check_pixel(60, 60, 2, covered_red, 2);  }
 		else { check_pixel(60, 60, 2, red, 2);  }
 	}
 
+	tmp = text->get_text_value();
+	tmp2 = text2->get_text_value();
+
 	// roll off the square, this should change
 	// the textfield value, if enabled
 	tester.movePointerTo(39, 60);
-	check_equals(string(text->get_text_value()), string("MouseOut"));
-	check_equals(string(text2->get_text_value()), string("RollOut"));
+	if ( enabled ) {
+		check_equals(string(text->get_text_value()), string("RollOut"));
+		check_equals(string(text2->get_text_value()), tmp2);
+	} else {
+		check_equals(string(text->get_text_value()), tmp);
+		check_equals(string(text2->get_text_value()), tmp2);
+	}
 	check(!tester.isMouseOverMouseEntity());
 	// check that pixel @ 60,60 is red !
 	if ( covered ) { check_pixel(60, 60, 2, covered_red, 2); }
 	else { check_pixel(60, 60, 2, red, 2); }
 
+	tmp = text->get_text_value();
+	tmp2 = text2->get_text_value();
+
 	// press the mouse button, this should not change anything
 	// as we're outside of the button.
 	tester.pressMouseButton();
-	check_equals(string(text->get_text_value()), string("MouseOut"));
-	check_equals(string(text2->get_text_value()), string("RollOut"));
+	check_equals(string(text->get_text_value()), tmp);
+	check_equals(string(text2->get_text_value()), string("MouseDown"));
 	check(!tester.isMouseOverMouseEntity());
 	// check that pixel @ 60,60 is red !
 	if ( covered ) { check_pixel(60, 60, 2, covered_red, 2); }
@@ -121,8 +136,8 @@ test_mouse_activity(MovieTester& tester, const character* text, const character*
 	// depress the mouse button, this should not change anything
 	// as we're outside of the button.
 	tester.depressMouseButton();
-	check_equals(string(text->get_text_value()), string("MouseOut"));
-	check_equals(string(text2->get_text_value()), string("RollOut"));
+	check_equals(string(text->get_text_value()), tmp);
+	check_equals(string(text2->get_text_value()), string("MouseUp"));
 	check(!tester.isMouseOverMouseEntity());
 	// check that pixel @ 60,60 is red !
 	if ( covered ) { check_pixel(60, 60, 2, covered_red, 2); }
@@ -133,16 +148,16 @@ test_mouse_activity(MovieTester& tester, const character* text, const character*
 	tester.movePointerTo(60, 60); 
 
 	if ( enabled ) {
-		check_equals(string(text->get_text_value()), string("MouseOver"));
-		check_equals(string(text2->get_text_value()), string("RollOver"));
+		check_equals(string(text->get_text_value()), string("RollOver"));
+		check_equals(string(text2->get_text_value()), tmp2);
 		check(tester.isMouseOverMouseEntity());
 		// check that pixel @ 60,60 is yellow !
 		if ( covered ) { check_pixel(60, 60, 2, covered_yellow, 2);  }
 		else { check_pixel(60, 60, 2, yellow, 2);  }
 	} else {
-		check_equals(string(text->get_text_value()), string("MouseOut"));
-		check_equals(string(text2->get_text_value()), string("RollOut"));
-		check(!tester.isMouseOverMouseEntity());
+		check_equals(string(text->get_text_value()), tmp);
+		check_equals(string(text2->get_text_value()), tmp2);
+		check(!tester.isMouseOverMouseEntity()); 
 		// check that pixel @ 60,60 is red !
 		if ( covered ) { check_pixel(60, 60, 2, covered_red, 2); }
 		else { check_pixel(60, 60, 2, red, 2); }
@@ -151,15 +166,15 @@ test_mouse_activity(MovieTester& tester, const character* text, const character*
 	tester.pressMouseButton();
 
 	if ( enabled ) {
-		check_equals(string(text->get_text_value()), string("MouseDown"));
-		check_equals(string(text2->get_text_value()), string("Press"));
+		check_equals(string(text->get_text_value()), string("Press"));
+		check_equals(string(text2->get_text_value()), string("MouseDown"));
 		check(tester.isMouseOverMouseEntity());
 		// check that pixel @ 60,60 is green !
 		check_pixel(60, 60, 2, rgba(0,255,0,255), 2);
 	} else {
-		check_equals(string(text->get_text_value()), string("MouseOut"));
-		check_equals(string(text2->get_text_value()), string("RollOut"));
-		check(!tester.isMouseOverMouseEntity());
+		check_equals(string(text->get_text_value()), tmp);
+		check_equals(string(text2->get_text_value()), string("MouseDown"));
+		check(!tester.isMouseOverMouseEntity()); 
 		// check that pixel @ 60,60 is red !
 		if ( covered ) { check_pixel(60, 60, 2, covered_red, 2); }
 		else { check_pixel(60, 60, 2, red, 2); }
@@ -172,11 +187,11 @@ test_mouse_activity(MovieTester& tester, const character* text, const character*
 	tester.depressMouseButton();
 
 	if ( enabled ) {
-		xcheck_equals(string(text->get_text_value()), string("MouseUpOutside"));
-		xcheck_equals(string(text2->get_text_value()), string("ReleaseOutside"));
+		check_equals(string(text->get_text_value()), string("ReleaseOutside")); 
+		check_equals(string(text2->get_text_value()), "MouseUp");
 	} else {
-		check_equals(string(text->get_text_value()), string("MouseOut"));
-		check_equals(string(text2->get_text_value()), string("RollOut"));
+		check_equals(string(text->get_text_value()), string("ReleaseOutside"));
+		check_equals(string(text2->get_text_value()), "MouseUp");
 	}
 }
 
@@ -192,14 +207,9 @@ main(int /*argc*/, char** /*argv*/)
 	sprite_instance* root = tester.getRootMovie();
 	assert(root);
 
-	check_equals(root->get_frame_count(), 4);
-
+	check_equals(root->get_frame_count(), 5);
 	check_equals(root->get_current_frame(), 0);
 
-	const character* mc1 = tester.findDisplayItemByName(*root, "square1");
-	check(mc1);
-	check_equals(mc1->get_depth(), 2+character::staticDepthOffset);
-
 	const character* text = tester.findDisplayItemByName(*root, "textfield");
 	check(text);
 
@@ -209,6 +219,14 @@ main(int /*argc*/, char** /*argv*/)
 	const character* text3 = tester.findDisplayItemByName(*root, "textfield3");
 	check(text3);
 
+	tester.advance();
+	check_equals(root->get_current_frame(), 1);
+
+	const character* mc1 = tester.findDisplayItemByName(*root, "square1");
+	check(mc1);
+	check_equals(mc1->get_depth(), 2+character::staticDepthOffset);
+
+
 	check_equals(string(text->get_text_value()), idleString);
 	check_equals(string(text2->get_text_value()), idleString);
 	check_equals(string(text3->get_text_value()), idleString);
@@ -217,22 +235,22 @@ main(int /*argc*/, char** /*argv*/)
 	rgba red(255,0,0,255);
 	check_pixel(60, 60, 2, red, 2);
 
-	for (size_t fno=0; fno<root->get_frame_count(); fno++)
+	for (size_t fno=1; fno<root->get_frame_count(); fno++)
 	{
 		const character* square_back = tester.findDisplayItemByDepth(*root, 1+character::staticDepthOffset);
 		const character* square_front = tester.findDisplayItemByDepth(*root, 3+character::staticDepthOffset);
 
 		switch (fno)
 		{
-			case 0:
+			case 1:
 				check(!square_back);
 				check(!square_front);
 				break;
-			case 1:
+			case 2:
 				check(square_back);
 				check(!square_front);
 				break;
-			case 2:
+			case 3:
 				check(square_back);
 				check(square_front);
 				break;
@@ -250,8 +268,9 @@ main(int /*argc*/, char** /*argv*/)
 
 	}
 
-	// last advance should restart the loop...
-	check_equals(root->get_current_frame(), 0);
+	// last advance should not restart the loop (it's in STOP mode)
+        check_equals(root->get_play_state(), sprite_instance::STOP);
+	check_equals(root->get_current_frame(), 4);
 
 }
 
